@@ -22,19 +22,41 @@ if((length(filesRData) > 0)&&(regPred==TRUE)){
 filesRDataCols <- gsubfn(".*Control_","",filesRData)
 filesRDataCols <- gsubfn(".RData","",filesRDataCols)
 
+
+if(.Platform$OS.type != "windows"){
+
 varImpRDataOutfileRMSE <- paste("./",skel_outfile, "VarImpRes_RMSE.RData",sep="")
 varImpTxtOutfileRMSE <- paste("./",skel_outfile, "VarImpRes_RMSE.txt",sep="")
 
 varImpRDataOutfileMSE <- paste("./",skel_outfile, "VarImpRes_MSE.RData",sep="")
 varImpTxtOutfileMSE <- paste("./",skel_outfile, "VarImpRes_MSE.txt",sep="")
 
+} else if (.Platform$OS.type == "windows"){
+
+varImpRDataOutfileRMSE <- paste(skel_outfile, "VarImpRes_RMSE.RData",sep="")
+varImpTxtOutfileRMSE <- paste(skel_outfile, "VarImpRes_RMSE.txt",sep="")
+
+varImpRDataOutfileMSE <- paste(skel_outfile, "VarImpRes_MSE.RData",sep="")
+varImpTxtOutfileMSE <- paste(skel_outfile, "VarImpRes_MSE.txt",sep="")
+
+
+}
+
 cat("\n----Processing files:----\n")
 print(filesRData)
 
 for (i in 1:length(filesRData)){
 
+if(.Platform$OS.type != "windows"){
+
 load(paste(tempdir(),"/",filesRData[i],sep=""))
 
+} else {
+
+load(paste(tempdir(),"\\",filesRData[i],sep=""))
+
+}
+
 print("")
 print("Calculating error for model:")
 print(filesRData[i])
@@ -130,8 +152,18 @@ for(i in 1:length(filesVarImp)){
 currentFile <- filesVarImp[i]
 
 # read file
+if(.Platform$OS.type != "windows"){
+
 tempDF <- read.csv(paste(tempdir(),"/",filesVarImp[i],sep=""),header=TRUE,sep="\t", strip.white = TRUE, na.strings = c("NA",""))
 
+} else if (.Platform$OS.type == "windows"){
+
+tempDF <- read.csv(paste(tempdir(),"\\",filesVarImp[i],sep=""),header=TRUE,sep="\t", strip.white = TRUE, na.strings = c("NA",""))
+
+}
+
+
+
 if(ncol(tempDF) > 1){
 
 tempDF <- as.data.frame(rowSums(tempDF))
@@ -307,8 +339,17 @@ print(filesRData)
 
 for (i in 1:length(filesRData)){
 
+
+if(.Platform$OS.type != "windows"){
+
 load(paste(tempdir(),"/",filesRData[i],sep=""))
 
+} else if(.Platform$OS.type == "windows"){
+
+load(paste(tempdir(),"\\",filesRData[i],sep=""))
+
+}
+
 print("")
 print("Calculating error measure for model:")
 print(filesRData[i])
@@ -421,9 +462,20 @@ for(i in 1:length(filesVarImp)){
 
 currentFile <- filesVarImp[i]
 
+
 # read file
+
+if(.Platform$OS.type != "windows"){
+
 tempDF <- read.csv(paste(tempdir(),"/",filesVarImp[i],sep=""),header=TRUE,sep="\t", strip.white = TRUE, na.strings = c("NA",""))
 
+} else if(.Platform$OS.type == "windows"){
+
+tempDF <- read.csv(paste(tempdir(),"\\",filesVarImp[i],sep=""),header=TRUE,sep="\t", strip.white = TRUE, na.strings = c("NA",""))
+
+}
+
+
 if(ncol(tempDF) > 1){
 
 tempDF <- as.data.frame(rowSums(tempDF))
